measuretools
============

.. automodule:: abjad.tools.measuretools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.measuretools.Measure.Measure.Measure

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.measuretools.append_spacer_skip_to_underfull_measure.append_spacer_skip_to_underfull_measure
      ~abjad.tools.measuretools.append_spacer_skips_to_underfull_measures_in_expr.append_spacer_skips_to_underfull_measures_in_expr
      ~abjad.tools.measuretools.apply_full_measure_tuplets_to_contents_of_measures_in_expr.apply_full_measure_tuplets_to_contents_of_measures_in_expr
      ~abjad.tools.measuretools.extend_measures_in_expr_and_apply_full_measure_tuplets.extend_measures_in_expr_and_apply_full_measure_tuplets
      ~abjad.tools.measuretools.fill_measures_in_expr_with_full_measure_spacer_skips.fill_measures_in_expr_with_full_measure_spacer_skips
      ~abjad.tools.measuretools.fill_measures_in_expr_with_minimal_number_of_notes.fill_measures_in_expr_with_minimal_number_of_notes
      ~abjad.tools.measuretools.fill_measures_in_expr_with_repeated_notes.fill_measures_in_expr_with_repeated_notes
      ~abjad.tools.measuretools.fill_measures_in_expr_with_time_signature_denominator_notes.fill_measures_in_expr_with_time_signature_denominator_notes
      ~abjad.tools.measuretools.get_measure_that_starts_with_container.get_measure_that_starts_with_container
      ~abjad.tools.measuretools.get_measure_that_stops_with_container.get_measure_that_stops_with_container
      ~abjad.tools.measuretools.get_next_measure_from_component.get_next_measure_from_component
      ~abjad.tools.measuretools.get_one_indexed_measure_number_in_expr.get_one_indexed_measure_number_in_expr
      ~abjad.tools.measuretools.get_previous_measure_from_component.get_previous_measure_from_component
      ~abjad.tools.measuretools.make_measures_with_full_measure_spacer_skips.make_measures_with_full_measure_spacer_skips
      ~abjad.tools.measuretools.move_full_measure_tuplet_prolation_to_measure_time_signature.move_full_measure_tuplet_prolation_to_measure_time_signature
      ~abjad.tools.measuretools.move_measure_prolation_to_full_measure_tuplet.move_measure_prolation_to_full_measure_tuplet
      ~abjad.tools.measuretools.replace_contents_of_measures_in_expr.replace_contents_of_measures_in_expr
      ~abjad.tools.measuretools.scale_measure_denominator_and_adjust_measure_contents.scale_measure_denominator_and_adjust_measure_contents
      ~abjad.tools.measuretools.set_always_format_time_signature_of_measures_in_expr.set_always_format_time_signature_of_measures_in_expr
      ~abjad.tools.measuretools.set_measure_denominator_and_adjust_numerator.set_measure_denominator_and_adjust_numerator
